@@ -22,3 +22,8 @@ STATIC_ROOT = ''
 STATICFILES_DIRS = (
     STATICFILES_ROOT,
 )
+
+PASSWORD_HASHERS = [
+    'django.contrib.auth.hashers.PBKDF2PasswordHasher',
+    'django.contrib.auth.hashers.MD5PasswordHasher',
+]
